@@ -3,9 +3,7 @@ import glob
 import operator
 import os
 import platform
-import subprocess
 import time
-import warnings
 from typing import List, Optional, Tuple, Union
 
 if platform.system() == 'Linux':
@@ -771,32 +769,6 @@ class XRandr:
             valid_displays = filter_monitors(display=display, haystack=valid_displays, include=['interface'])
         return valid_displays
 
-    @classmethod
-    def get_display_interfaces(cls) -> List[str]:
-        '''
-        *DEPRECATED*  
-        Returns the interfaces of each display, as reported by xrandr
-
-        Returns:
-            list: list of strings
-
-        Example:
-            ```python
-            import screen_brightness_control as sbc
-
-            names = sbc.linux.XRandr.get_display_interfaces()
-            # EG output: ['eDP-1', 'HDMI1', 'HDMI2']
-            ```
-        '''
-        warnings.warn(
-            (
-                'XRandr.get_display_interfaces is deprecated and will be removed in the next release.'
-                ' Please use XRandr.get_display_info instead'
-            ), DeprecationWarning
-        )
-        out = subprocess.check_output([cls.executable, '-q']).decode().split('\n')
-        return [i.split(' ')[0] for i in out if 'connected' in i and 'disconnected' not in i]
-
     @classmethod
     def get_brightness(cls, display: Optional[int] = None) -> List[int]:
         '''
@@ -908,7 +880,7 @@ class DDCUtil:
             raw_ddcutil_output = str(
                 check_output(
                     [
-                        cls.executable, 'detect', '-v',
+                        cls.executable, 'detect', '-v', '--async',
                         f'--sleep-multiplier={cls.sleep_multiplier}'
                     ], max_tries=10
                 )
@@ -1134,18 +1106,22 @@ def list_monitors_info(method: Optional[str] = None, allow_duplicates: bool = Fa
         if method not in all_methods:
             raise ValueError(f'method must be one of: {list(all_methods)}')
 
-    info = []
-    edids = []
-    for method_name, method_class in all_methods.items():
-        if method is None or method == method_name:
-            # to make sure each display (with unique edid) is only reported once
-            try:
-                tmp = method_class.get_display_info()
-            except Exception:
-                pass
-            else:
-                for i in tmp:
-                    if allow_duplicates or i['edid'] not in edids:
-                        edids.append(i['edid'])
-                        info.append(i)
-    return info
+    all_methods = all_methods.values()
+
+    haystack = []
+    for method_class in all_methods:
+        if method is not None and method != method_class.__name__.lower():
+            continue
+        try:
+            haystack += method_class.get_display_info()
+        except Exception:
+            pass
+
+    if allow_duplicates:
+        return haystack
+
+    try:
+        # use filter_monitors to remove duplicates
+        return filter_monitors(haystack=haystack)
+    except LookupError:
+        return []
